==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/SQLQUERYDETAIL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SQLQUERYDETAIL_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SQLQUERYDETAIL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUERYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SQLSTATEMENT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SQLQUERYDETAIL_Type", propOrder = {
    "querycode",
    "sqlstatement"
})
public class SQLQUERYDETAIL_Type {

    @XmlElement(name = "QUERYCODE", required = true)
    protected String querycode;
    @XmlElement(name = "SQLSTATEMENT")
    protected String sqlstatement;

    /**
     * Obtient la valeur de la propriété querycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUERYCODE() {
        return querycode;
    }

    /**
     * Définit la valeur de la propriété querycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUERYCODE(String value) {
        this.querycode = value;
    }

    /**
     * Obtient la valeur de la propriété sqlstatement.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSQLSTATEMENT() {
        return sqlstatement;
    }

    /**
     * Définit la valeur de la propriété sqlstatement.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSQLSTATEMENT(String value) {
        this.sqlstatement = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/SQLQUERYDETAIL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SQLQUERYDETAIL_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SQLQUERYDETAIL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUERYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SQLSTATEMENT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SQLQUERYDETAIL_Type", propOrder = {
    "querycode",
    "sqlstatement"
})
public class SQLQUERYDETAIL_Type {

    @XmlElement(name = "QUERYCODE", required = true)
    protected String querycode;
    @XmlElement(name = "SQLSTATEMENT")
    protected String sqlstatement;

    /**
     * Gets the value of the querycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUERYCODE() {
        return querycode;
    }

    /**
     * Sets the value of the querycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUERYCODE(String value) {
        this.querycode = value;
    }

    /**
     * Gets the value of the sqlstatement property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSQLSTATEMENT() {
        return sqlstatement;
    }

    /**
     * Sets the value of the sqlstatement property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSQLSTATEMENT(String value) {
        this.sqlstatement = value;
    }

}
